@@ -229,176 +229,176 @@ class ParseTest(unittest.TestCase):
         self.assertEqual(len(m1), 3)
         # Deconstruct this data structure to check each chain
         chain_data = [  # chain_id, chain_len, [(residue_id, residue_len), ...]
-            ('A', 86, [ ((' ', 0, ' '), 1 ),
-                        ((' ', 2, ' '), 11),
-                        ((' ', 3, ' '), 6, 1),  # disordered
-                        ((' ', 4, ' '), 4 ),
-                        ((' ', 5, ' '), 6 ),
-                        ((' ', 6, ' '), 9 ),
-                        ((' ', 7, ' '), 4 ),
-                        ((' ', 8, ' '), 4 ),
-                        ((' ', 9, ' '), 4 ),
-                        ((' ', 10, ' '), 6, ['GLY', 'SER']),  # point mut
-                        ((' ', 11, ' '), 7 ),
-                        ((' ', 12, ' '), 6 ),
-                        ((' ', 13, ' '), 7 ),
-                        ((' ', 14, ' '), 4, ['ALA', 'GLY']),  # point mut
-                        ((' ', 15, ' '), 8, 3),  # disordered
-                        ((' ', 16, ' '), 11, ['ARG', 'TRP']),  # point mut
-                        ((' ', 17, ' '), 6 ),
-                        ((' ', 18, ' '), 6 ),
-                        ((' ', 19, ' '), 6 ),
-                        ((' ', 20, ' '), 8 ),
-                        ((' ', 21, ' '), 14),
-                        ((' ', 22, ' '), 4 ),
-                        ((' ', 23, ' '), 14),
-                        ((' ', 24, ' '), 6 ),
-                        ((' ', 25, ' '), 4 ),
-                        ((' ', 26, ' '), 8 ),
-                        ((' ', 27, ' '), 6 ),
-                        ((' ', 28, ' '), 9, 5),  # disordered
-                        ((' ', 29, ' '), 7 ),
-                        ((' ', 30, ' '), 12),
-                        ((' ', 31, ' '), 6 ),
-                        ((' ', 32, ' '), 4 ),
-                        ((' ', 33, ' '), 11),
-                        ((' ', 34, ' '), 7 ),
-                        ((' ', 35, ' '), 6 ),
-                        ((' ', 36, ' '), 9 ),
-                        ((' ', 37, ' '), 8 ),
-                        ((' ', 38, ' '), 9 ),
-                        ((' ', 39, ' '), 6 ),
-                        ((' ', 40, ' '), 14),
-                        ((' ', 41, ' '), 6 ),
-                        ((' ', 42, ' '), 4 ),
-                        ((' ', 43, ' '), 9 ),
-                        ((' ', 44, ' '), 11),
-                        ((' ', 45, ' '), 6, 1),  # disordered
-                        ((' ', 46, ' '), 8 ),
-                        ((' ', 47, ' '), 10),
-                        ((' ', 48, ' '), 11),
-                        ((' ', 49, ' '), 6 ),
-                        ((' ', 50, ' '), 4 ),
-                        ((' ', 51, ' '), 5 ),
-                        ((' ', 52, ' '), 5 ),
-                        ((' ', 53, ' '), 7 ),
-                        ((' ', 54, ' '), 4 ),
-                        ((' ', 55, ' '), 8 ),
-                        ((' ', 56, ' '), 7 ),
-                        ((' ', 57, ' '), 7 ),
-                        ((' ', 58, ' '), 6 ),
-                        ((' ', 59, ' '), 4 ),
-                        ((' ', 60, ' '), 9 ),
-                        ((' ', 61, ' '), 8 ),
-                        ((' ', 62, ' '), 11),
-                        ((' ', 63, ' '), 6 ),
-                        ((' ', 64, ' '), 6 ),
-                        ((' ', 65, ' '), 6 ),
-                        ((' ', 66, ' '), 7 ),
-                        ((' ', 67, ' '), 10),
-                        ((' ', 68, ' '), 4 ),
-                        ((' ', 69, ' '), 14),
-                        ((' ', 70, ' '), 6 ),
-                        ((' ', 71, ' '), 4 ),
-                        ((' ', 72, ' '), 4 ),
-                        ((' ', 73, ' '), 4 ),
-                        ((' ', 74, ' '), 8, 3),  # disordered
-                        ((' ', 75, ' '), 8 ),
-                        ((' ', 76, ' '), 12),
-                        ((' ', 77, ' '), 6 ),
-                        ((' ', 78, ' '), 6 ),
-                        ((' ', 79, ' '), 4, 4),  # disordered
-                        ((' ', 80, ' '), 4, ['GLY', 'SER']),  # point mut
-                        ((' ', 81, ' '), 8, ['ASN', 'LYS']),  # point mut
-                        ((' ', 82, ' '), 6 ),
-                        ((' ', 83, ' '), 9 ),
-                        ((' ', 84, ' '), 12),
-                        ((' ', 85, ' '), 11),
-                        ((' ', 86, ' '), 6 ),
-                        ]),
-            ('B', 4, [ (('H_NAG', 1, ' '), 14),
-                        (('H_NAG', 2, ' '), 14),
-                        (('H_NAG', 3, ' '), 14),
-                        (('H_NAG', 4, ' '), 14),
-                        ]),
-            (' ', 76, [ (('W', 1, ' '), 1),
-                        (('W', 2, ' '), 1),
-                        (('W', 3, ' '), 1),
-                        (('W', 4, ' '), 1),
-                        (('W', 5, ' '), 1),
-                        (('W', 6, ' '), 1),
-                        (('W', 7, ' '), 1),
-                        (('W', 8, ' '), 1),
-                        (('W', 9, ' '), 1),
-                        (('W', 10, ' '), 1),
-                        (('W', 11, ' '), 1),
-                        (('W', 12, ' '), 1),
-                        (('W', 13, ' '), 1),
-                        (('W', 14, ' '), 1),
-                        (('W', 15, ' '), 1),
-                        (('W', 16, ' '), 1),
-                        (('W', 17, ' '), 1),
-                        (('W', 18, ' '), 1),
-                        (('W', 19, ' '), 1),
-                        (('W', 20, ' '), 1),
-                        (('W', 21, ' '), 1),
-                        (('W', 22, ' '), 1),
-                        (('W', 23, ' '), 1),
-                        (('W', 24, ' '), 1),
-                        (('W', 25, ' '), 1),
-                        (('W', 26, ' '), 1),
-                        (('W', 27, ' '), 1),
-                        (('W', 28, ' '), 1),
-                        (('W', 29, ' '), 1),
-                        (('W', 30, ' '), 1),
-                        (('W', 31, ' '), 1),
-                        (('W', 32, ' '), 1),
-                        (('W', 33, ' '), 1),
-                        (('W', 34, ' '), 1),
-                        (('W', 35, ' '), 1),
-                        (('W', 36, ' '), 1),
-                        (('W', 37, ' '), 1),
-                        (('W', 38, ' '), 1),
-                        (('W', 39, ' '), 1),
-                        (('W', 40, ' '), 1),
-                        (('W', 41, ' '), 1),
-                        (('W', 42, ' '), 1),
-                        (('W', 43, ' '), 1),
-                        (('W', 44, ' '), 1),
-                        (('W', 45, ' '), 1),
-                        (('W', 46, ' '), 1),
-                        (('W', 47, ' '), 1),
-                        (('W', 48, ' '), 1),
-                        (('W', 49, ' '), 1),
-                        (('W', 50, ' '), 1),
-                        (('W', 51, ' '), 1),
-                        (('W', 52, ' '), 1),
-                        (('W', 53, ' '), 1),
-                        (('W', 54, ' '), 1),
-                        (('W', 55, ' '), 1),
-                        (('W', 56, ' '), 1),
-                        (('W', 57, ' '), 1),
-                        (('W', 58, ' '), 1),
-                        (('W', 59, ' '), 1),
-                        (('W', 60, ' '), 1),
-                        (('W', 61, ' '), 1),
-                        (('W', 62, ' '), 1),
-                        (('W', 63, ' '), 1),
-                        (('W', 64, ' '), 1),
-                        (('W', 65, ' '), 1),
-                        (('W', 66, ' '), 1),
-                        (('W', 67, ' '), 1),
-                        (('W', 68, ' '), 1),
-                        (('W', 69, ' '), 1),
-                        (('W', 70, ' '), 1),
-                        (('W', 71, ' '), 1),
-                        (('W', 72, ' '), 1),
-                        (('W', 73, ' '), 1),
-                        (('W', 74, ' '), 1),
-                        (('W', 75, ' '), 1),
-                        (('W', 77, ' '), 1),
-                        ])
-                        ]
+            ('A', 86, [((' ', 0, ' '), 1),
+                       ((' ', 2, ' '), 11),
+                       ((' ', 3, ' '), 6, 1),  # disordered
+                       ((' ', 4, ' '), 4),
+                       ((' ', 5, ' '), 6),
+                       ((' ', 6, ' '), 9),
+                       ((' ', 7, ' '), 4),
+                       ((' ', 8, ' '), 4),
+                       ((' ', 9, ' '), 4),
+                       ((' ', 10, ' '), 6, ['GLY', 'SER']),  # point mut
+                       ((' ', 11, ' '), 7),
+                       ((' ', 12, ' '), 6),
+                       ((' ', 13, ' '), 7),
+                       ((' ', 14, ' '), 4, ['ALA', 'GLY']),  # point mut
+                       ((' ', 15, ' '), 8, 3),  # disordered
+                       ((' ', 16, ' '), 11, ['ARG', 'TRP']),  # point mut
+                       ((' ', 17, ' '), 6),
+                       ((' ', 18, ' '), 6),
+                       ((' ', 19, ' '), 6),
+                       ((' ', 20, ' '), 8),
+                       ((' ', 21, ' '), 14),
+                       ((' ', 22, ' '), 4),
+                       ((' ', 23, ' '), 14),
+                       ((' ', 24, ' '), 6),
+                       ((' ', 25, ' '), 4),
+                       ((' ', 26, ' '), 8),
+                       ((' ', 27, ' '), 6),
+                       ((' ', 28, ' '), 9, 5),  # disordered
+                       ((' ', 29, ' '), 7),
+                       ((' ', 30, ' '), 12),
+                       ((' ', 31, ' '), 6),
+                       ((' ', 32, ' '), 4),
+                       ((' ', 33, ' '), 11),
+                       ((' ', 34, ' '), 7),
+                       ((' ', 35, ' '), 6),
+                       ((' ', 36, ' '), 9),
+                       ((' ', 37, ' '), 8),
+                       ((' ', 38, ' '), 9),
+                       ((' ', 39, ' '), 6),
+                       ((' ', 40, ' '), 14),
+                       ((' ', 41, ' '), 6),
+                       ((' ', 42, ' '), 4),
+                       ((' ', 43, ' '), 9),
+                       ((' ', 44, ' '), 11),
+                       ((' ', 45, ' '), 6, 1),  # disordered
+                       ((' ', 46, ' '), 8),
+                       ((' ', 47, ' '), 10),
+                       ((' ', 48, ' '), 11),
+                       ((' ', 49, ' '), 6),
+                       ((' ', 50, ' '), 4),
+                       ((' ', 51, ' '), 5),
+                       ((' ', 52, ' '), 5),
+                       ((' ', 53, ' '), 7),
+                       ((' ', 54, ' '), 4),
+                       ((' ', 55, ' '), 8),
+                       ((' ', 56, ' '), 7),
+                       ((' ', 57, ' '), 7),
+                       ((' ', 58, ' '), 6),
+                       ((' ', 59, ' '), 4),
+                       ((' ', 60, ' '), 9),
+                       ((' ', 61, ' '), 8),
+                       ((' ', 62, ' '), 11),
+                       ((' ', 63, ' '), 6),
+                       ((' ', 64, ' '), 6),
+                       ((' ', 65, ' '), 6),
+                       ((' ', 66, ' '), 7),
+                       ((' ', 67, ' '), 10),
+                       ((' ', 68, ' '), 4),
+                       ((' ', 69, ' '), 14),
+                       ((' ', 70, ' '), 6),
+                       ((' ', 71, ' '), 4),
+                       ((' ', 72, ' '), 4),
+                       ((' ', 73, ' '), 4),
+                       ((' ', 74, ' '), 8, 3),  # disordered
+                       ((' ', 75, ' '), 8),
+                       ((' ', 76, ' '), 12),
+                       ((' ', 77, ' '), 6),
+                       ((' ', 78, ' '), 6),
+                       ((' ', 79, ' '), 4, 4),  # disordered
+                       ((' ', 80, ' '), 4, ['GLY', 'SER']),  # point mut
+                       ((' ', 81, ' '), 8, ['ASN', 'LYS']),  # point mut
+                       ((' ', 82, ' '), 6),
+                       ((' ', 83, ' '), 9),
+                       ((' ', 84, ' '), 12),
+                       ((' ', 85, ' '), 11),
+                       ((' ', 86, ' '), 6),
+                       ]),
+            ('B', 4, [(('H_NAG', 1, ' '), 14),
+                      (('H_NAG', 2, ' '), 14),
+                      (('H_NAG', 3, ' '), 14),
+                      (('H_NAG', 4, ' '), 14),
+                      ]),
+            (' ', 76, [(('W', 1, ' '), 1),
+                       (('W', 2, ' '), 1),
+                       (('W', 3, ' '), 1),
+                       (('W', 4, ' '), 1),
+                       (('W', 5, ' '), 1),
+                       (('W', 6, ' '), 1),
+                       (('W', 7, ' '), 1),
+                       (('W', 8, ' '), 1),
+                       (('W', 9, ' '), 1),
+                       (('W', 10, ' '), 1),
+                       (('W', 11, ' '), 1),
+                       (('W', 12, ' '), 1),
+                       (('W', 13, ' '), 1),
+                       (('W', 14, ' '), 1),
+                       (('W', 15, ' '), 1),
+                       (('W', 16, ' '), 1),
+                       (('W', 17, ' '), 1),
+                       (('W', 18, ' '), 1),
+                       (('W', 19, ' '), 1),
+                       (('W', 20, ' '), 1),
+                       (('W', 21, ' '), 1),
+                       (('W', 22, ' '), 1),
+                       (('W', 23, ' '), 1),
+                       (('W', 24, ' '), 1),
+                       (('W', 25, ' '), 1),
+                       (('W', 26, ' '), 1),
+                       (('W', 27, ' '), 1),
+                       (('W', 28, ' '), 1),
+                       (('W', 29, ' '), 1),
+                       (('W', 30, ' '), 1),
+                       (('W', 31, ' '), 1),
+                       (('W', 32, ' '), 1),
+                       (('W', 33, ' '), 1),
+                       (('W', 34, ' '), 1),
+                       (('W', 35, ' '), 1),
+                       (('W', 36, ' '), 1),
+                       (('W', 37, ' '), 1),
+                       (('W', 38, ' '), 1),
+                       (('W', 39, ' '), 1),
+                       (('W', 40, ' '), 1),
+                       (('W', 41, ' '), 1),
+                       (('W', 42, ' '), 1),
+                       (('W', 43, ' '), 1),
+                       (('W', 44, ' '), 1),
+                       (('W', 45, ' '), 1),
+                       (('W', 46, ' '), 1),
+                       (('W', 47, ' '), 1),
+                       (('W', 48, ' '), 1),
+                       (('W', 49, ' '), 1),
+                       (('W', 50, ' '), 1),
+                       (('W', 51, ' '), 1),
+                       (('W', 52, ' '), 1),
+                       (('W', 53, ' '), 1),
+                       (('W', 54, ' '), 1),
+                       (('W', 55, ' '), 1),
+                       (('W', 56, ' '), 1),
+                       (('W', 57, ' '), 1),
+                       (('W', 58, ' '), 1),
+                       (('W', 59, ' '), 1),
+                       (('W', 60, ' '), 1),
+                       (('W', 61, ' '), 1),
+                       (('W', 62, ' '), 1),
+                       (('W', 63, ' '), 1),
+                       (('W', 64, ' '), 1),
+                       (('W', 65, ' '), 1),
+                       (('W', 66, ' '), 1),
+                       (('W', 67, ' '), 1),
+                       (('W', 68, ' '), 1),
+                       (('W', 69, ' '), 1),
+                       (('W', 70, ' '), 1),
+                       (('W', 71, ' '), 1),
+                       (('W', 72, ' '), 1),
+                       (('W', 73, ' '), 1),
+                       (('W', 74, ' '), 1),
+                       (('W', 75, ' '), 1),
+                       (('W', 77, ' '), 1),
+                       ])
+            ]
 
         for c_idx, chn in enumerate(chain_data):
             # Check chain ID and length
@@ -823,10 +823,10 @@ class Exposure(unittest.TestCase):
         pdb_filename = "PDB/a_structure.pdb"
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", PDBConstructionWarning)
-            structure=PDBParser(PERMISSIVE=True).get_structure('X', pdb_filename)
-        self.model=structure[1]
+            structure = PDBParser(PERMISSIVE=True).get_structure('X', pdb_filename)
+        self.model = structure[1]
         # Look at first chain only
-        a_residues=list(self.model["A"].child_list)
+        a_residues = list(self.model["A"].child_list)
         self.assertEqual(86, len(a_residues))
         self.assertEqual(a_residues[0].get_resname(), "CYS")
         self.assertEqual(a_residues[1].get_resname(), "ARG")
@@ -907,7 +907,7 @@ class Atom_Element(unittest.TestCase):
         pdb_filename = "PDB/a_structure.pdb"
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", PDBConstructionWarning)
-            structure=PDBParser(PERMISSIVE=True).get_structure('X', pdb_filename)
+            structure = PDBParser(PERMISSIVE=True).get_structure('X', pdb_filename)
         self.residue = structure[0]['A'][('H_PCA', 1, ' ')]
 
     def test_AtomElement(self):
@@ -920,7 +920,7 @@ class Atom_Element(unittest.TestCase):
     def test_ions(self):
         """Element for magnesium is assigned correctly."""
         pdb_filename = "PDB/ions.pdb"
-        structure=PDBParser(PERMISSIVE=True).get_structure('X', pdb_filename)
+        structure = PDBParser(PERMISSIVE=True).get_structure('X', pdb_filename)
         # check magnesium atom
         atoms = structure[0]['A'][('H_ MG', 1, ' ')].child_list
         self.assertEqual('MG', atoms[0].element)
@@ -932,15 +932,13 @@ class Atom_Element(unittest.TestCase):
                              fullname, None).element
 
         pdb_elements = dict(
-            H=(
-                ' H  ', ' HA ', ' HB ', ' HD1', ' HD2', ' HE ', ' HE1', ' HE2',
-                ' HE3', ' HG ', ' HG1', ' HH ', ' HH2', ' HZ ', ' HZ2', ' HZ3',
-                '1H  ', '1HA ', '1HB ', '1HD ', '1HD1', '1HD2', '1HE ', '1HE2',
-                '1HG ', '1HG1', '1HG2', '1HH1', '1HH2', '1HZ ', '2H  ', '2HA ',
-                '2HB ', '2HD ', '2HD1', '2HD2', '2HE ', '2HE2', '2HG ', '2HG1',
-                '2HG2', '2HH1', '2HH2', '2HZ ', '3H  ', '3HB ', '3HD1', '3HD2',
-                '3HE ', '3HG1', '3HG2', '3HZ ', 'HE21',
-            ),
+            H=(' H  ', ' HA ', ' HB ', ' HD1', ' HD2', ' HE ', ' HE1', ' HE2',
+               ' HE3', ' HG ', ' HG1', ' HH ', ' HH2', ' HZ ', ' HZ2', ' HZ3',
+               '1H  ', '1HA ', '1HB ', '1HD ', '1HD1', '1HD2', '1HE ', '1HE2',
+               '1HG ', '1HG1', '1HG2', '1HH1', '1HH2', '1HZ ', '2H  ', '2HA ',
+               '2HB ', '2HD ', '2HD1', '2HD2', '2HE ', '2HE2', '2HG ', '2HG1',
+               '2HG2', '2HH1', '2HH2', '2HZ ', '3H  ', '3HB ', '3HD1', '3HD2',
+               '3HE ', '3HG1', '3HG2', '3HZ ', 'HE21'),
             O=(' OH ',),
             C=(' CH2',),
             N=(' NH1', ' NH2'),
@@ -972,7 +970,7 @@ class IterationTests(unittest.TestCase):
 
     def test_get_atoms(self):
         """Yields all atoms from the structure, excluding duplicates and ALTLOCs which are not parsed."""
-        atoms = ["%12s"%str((atom.id, atom.altloc)) for atom in self.struc.get_atoms()]
+        atoms = ["%12s" % str((atom.id, atom.altloc)) for atom in self.struc.get_atoms()]
         self.assertEqual(len(atoms), 756)
 
 
@@ -1022,13 +1020,13 @@ class TransformTests(unittest.TestCase):
         Returns the average atom position in an entity.
         """
         pos, count = self.get_total_pos(o)
-        return 1.0*pos/count
+        return 1.0 * pos / count
 
     def test_transform(self):
         """Transform entities (rotation and translation)."""
         for o in (self.s, self.m, self.c, self.r, self.a):
             rotation = rotmat(Vector(1, 3, 5), Vector(1, 0, 0))
-            translation=numpy.array((2.4, 0, 1), 'f')
+            translation = numpy.array((2.4, 0, 1), 'f')
             oldpos = self.get_pos(o)
             o.transform(rotation, translation)
             newpos = self.get_pos(o)
@@ -1076,6 +1074,26 @@ class DsspTests(unittest.TestCase):
         dssp, keys = make_dssp_dict("PDB/2BEG_noheader.dssp")
         self.assertEqual(len(dssp), 130)
 
+    def test_DSSP_hbonds(self):
+        """Test parsing of DSSP hydrogen bond information."""
+        dssp, keys = make_dssp_dict("PDB/2BEG.dssp")
+
+        dssp_indices = set(v[5] for v in dssp.values())
+        hb_indices = set()
+
+        # The integers preceding each hydrogen bond energy (kcal/mol) in the
+        # "N-H-->O    O-->H-N    N-H-->O    O-->H-N" dssp output columns are
+        # relative dssp indices. Therefore, "hb_indices" contains the absolute
+        # dssp indices of residues participating in (provisional) h-bonds. Note
+        # that actual h-bonds are typically determined by an energetic
+        # threshold.
+        for val in dssp.values():
+            hb_indices |= set(
+                (val[5] + x) for x in (val[6], val[8], val[10], val[12]))
+
+        # Check if all h-bond partner indices were successfully parsed.
+        self.assertEqual((dssp_indices & hb_indices), hb_indices)
+
 
 class NACCESSTests(unittest.TestCase):
     """Tests for NACCESS parsing etc which don't need the binary tool.
