@@ -11,10 +11,12 @@ import unittest
 from Bio import BiopythonExperimentalWarning
 
 import warnings
+
+
 with warnings.catch_warnings():
-   warnings.simplefilter('ignore', BiopythonExperimentalWarning)
-   from Bio.SearchIO import parse
-   from Bio.SearchIO.BlastIO.blast_tab import _LONG_SHORT_MAP as all_fields
+    warnings.simplefilter('ignore', BiopythonExperimentalWarning)
+    from Bio.SearchIO import parse
+    from Bio.SearchIO.BlastIO.blast_tab import _LONG_SHORT_MAP as all_fields
 
 # test case files are in the Blast directory
 TEST_DIR = 'Blast'
@@ -26,7 +28,24 @@ def get_file(filename):
     return os.path.join(TEST_DIR, filename)
 
 
-class BlastnTabCases(unittest.TestCase):
+class BlastTabCases(unittest.TestCase):
+
+    def test_tab_2228_tblastn_001(self):
+        "Test parsing TBLASTN 2.2.28+ tabular output (tab_2228_tblastn_001)"
+        tab_file = get_file('tab_2228_tblastn_001.txt')
+        qresults = list(parse(tab_file, FMT,
+                              fields=['evalue', 'sallseqid', 'qseqid'],
+                              comments=True))
+
+        self.assertEqual(1, len(qresults))
+        self.assertEqual(10, len(qresults[0].hits))
+        # there is one hit with an alternative ID
+        self.assertEqual(qresults[0]['gi|148227873|ref|NM_001095167.1|'],
+                qresults[0]['gi|55250552|gb|BC086280.1|'])
+
+        # check some of the HSPs
+        self.assertEqual(0.0, qresults[0][0][0].evalue)
+        self.assertEqual(8e-173, qresults[0][-1][0].evalue)
 
     def test_tab_2228_tblastx_001(self):
         "Test parsing TBLASTX 2.2.28+ tabular output (tab_2228_tblastx_001)"
@@ -39,6 +58,9 @@ class BlastnTabCases(unittest.TestCase):
         self.assertEqual(1, len(qresults))
         self.assertEqual(192, len(qresults[0].hits))
         self.assertEqual(243, sum([len(x) for x in qresults[0]]))
+        # there is one hit with an alternative ID
+        self.assertEqual(qresults[0]['gi|31126987|gb|AY255526.2|'],
+                qresults[0]['gi|31342050|ref|NM_181083.2|'])
 
         # only checking the new fields in 2.2.28+
         hit = qresults[0][0]
@@ -935,5 +957,5 @@ class BlastnTabCases(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    runner = unittest.TextTestRunner(verbosity = 2)
+    runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
