@@ -20,8 +20,8 @@ from Bio import BiopythonExperimentalWarning
 
 import warnings
 with warnings.catch_warnings():
-   warnings.simplefilter('ignore', BiopythonExperimentalWarning)
-   from Bio.SearchIO._model import QueryResult, Hit, HSP, HSPFragment
+    warnings.simplefilter('ignore', BiopythonExperimentalWarning)
+    from Bio.SearchIO._model import QueryResult, Hit, HSP, HSPFragment
 
 from Bio.Align import MultipleSeqAlignment
 from Bio.Alphabet import single_letter_alphabet, generic_dna
@@ -147,6 +147,14 @@ class QueryResultCases(unittest.TestCase):
         self.assertFalse('hit5' in self.qresult)
         self.assertFalse(hit41 in self.qresult)
 
+    def test_contains_alt(self):
+        """Test QueryResult.__contains__, with alternative IDs"""
+        # contains should work with alternative hit IDs
+        hit11._id_alt = ['alt1']
+        query = QueryResult([hit11])
+        self.assertTrue('alt1' in query)
+        hit11._id_alt = []
+
     def test_len(self):
         """Test QueryResult.__len__"""
         # len() should return the number of hits contained
@@ -168,6 +176,56 @@ class QueryResultCases(unittest.TestCase):
         self.qresult['hit4'] = hit11
         self.assertEqual([hit11, hit21, hit31, hit11], list(self.qresult.hits))
 
+    def test_setitem_ok_alt(self):
+        """Test QueryResult.__setitem__, checking alt hit IDs"""
+        # hit objects assignment should make alt IDs visible
+        hit11._id_alt = ['alt1', 'alt11']
+        query = QueryResult()
+        query['hit1'] = hit11
+        self.assertEqual(hit11, query['hit1'])
+        self.assertEqual(hit11, query['alt1'])
+        self.assertEqual(hit11, query['alt11'])
+        self.assertTrue(hit11.id != 'alt1')
+        self.assertTrue(hit11.id != 'alt11')
+        hit11._id_alt = []
+
+    def test_setitem_ok_alt_existing(self):
+        """Test QueryResult.__setitem__, existing key"""
+        # hit objects assignment on existing hits should also update alt IDs
+        hit11._id_alt = ['alt1']
+        hit21._id_alt = ['alt2']
+        query = QueryResult()
+        query['hit'] = hit11
+        self.assertEqual(hit11, query['hit'])
+        self.assertEqual(hit11, query['alt1'])
+        query['hit'] = hit21
+        self.assertEqual(hit21, query['hit'])
+        self.assertEqual(hit21, query['alt2'])
+        self.assertRaises(KeyError, query.__getitem__, 'alt1')
+        hit11._id_alt = []
+        hit21._id_alt = []
+
+    def test_setitem_ok_alt_ok_promote(self):
+        """Test QueryResult.__setitem__, previously alt ID"""
+        # hit objects assignment with ID previously existing as alternative
+        # should make the ID primary
+        hit11._id_alt = ['alt1']
+        hit41._id_alt = ['alt4']
+        hit31._id_alt = ['alt3']
+        query = QueryResult([hit11, hit41])
+        self.assertEqual(hit11, query['alt1'])
+        self.assertEqual(hit41, query['alt4'])
+        self.assertTrue('alt1' not in query._items)
+        self.assertTrue('alt1' in query._QueryResult__alt_hit_ids)
+        query['alt1'] = hit31
+        self.assertEqual(hit31, query['alt1'])
+        self.assertEqual(hit41, query['alt4'])
+        self.assertTrue('alt1' in query._items)
+        self.assertTrue('alt1' not in query._QueryResult__alt_hit_ids)
+        hit11._id_alt = []
+        hit41._id_alt = []
+        hit31._id_alt = []
+
     def test_setitem_wrong_key_type(self):
         """Test QueryResult.__setitem__, wrong key type"""
         # item assignment should fail if the key is not string
@@ -225,6 +283,33 @@ class QueryResultCases(unittest.TestCase):
         self.assertEqual(1102, new_qresult.seq_len)
         self.assertEqual('refseq_rna', new_qresult.target)
 
+    def test_getitm_slice_alt_ok(self):
+        """Test QueryResult.__getitem__, with slice and alt IDs"""
+        # slicing should be reflected in the alt IDs as well
+        hit31._id_alt = ['alt3']
+        hit11._id_alt = ['alt1']
+        query = QueryResult([hit31, hit11])
+        self.assertEqual(hit11, query['hit1'])
+        self.assertEqual(hit11, query['alt1'])
+        self.assertEqual(hit31, query['hit3'])
+        self.assertEqual(hit31, query['alt3'])
+        query = query[:1]
+        self.assertEqual(hit31, query['hit3'])
+        self.assertEqual(hit31, query['alt3'])
+        self.assertRaises(KeyError, query.__getitem__, 'hit1')
+        self.assertRaises(KeyError, query.__getitem__, 'alt1')
+        hit31._id_alt = []
+        hit11._id_alt = []
+
+    def test_getitem_alt_ok(self):
+        """Test QueryResult.__getitem__, single item with alternative ID"""
+        hit11._id_alt = ['alt1']
+        query = QueryResult([hit11])
+        self.assertEqual(hit11, query['hit1'])
+        self.assertEqual(hit11, query['alt1'])
+        self.assertTrue(hit11.id != 'alt1')
+        hit11._id_alt = []
+
     def test_delitem_string_ok(self):
         """Test QueryResult.__getitem__, with string"""
         # delitem should work with string index
@@ -249,6 +334,18 @@ class QueryResultCases(unittest.TestCase):
         self.assertEqual(1, len(self.qresult))
         self.assertTrue([hit31], self.qresult.hits)
 
+    def test_delitem_alt_ok(self):
+        """Test QueryResult.__delitem__, with alt ID"""
+        # delitem should work with alt IDs
+        hit31._id_alt = ['alt3']
+        qresult = QueryResult([hit31, hit41])
+        self.assertEqual(2, len(qresult))
+        del qresult['alt3']
+        self.assertEqual(1, len(qresult))
+        self.assertEqual(hit41, qresult['hit4'])
+        self.assertRaises(KeyError, qresult.__getitem__, 'alt3')
+        hit31._id_alt = []
+
     def test_description_set(self):
         """Test QueryResult.description setter"""
         # setting the description should change the query seqrecord description
@@ -356,9 +453,27 @@ class QueryResultCases(unittest.TestCase):
 
     def test_append_id_exists(self):
         """Test QueryResult.append, when ID exists"""
-        # append should raise an error if hit_key already exist
+        # append should raise an error if hit_key already exists
         self.assertRaises(ValueError, self.qresult.append, hit11)
 
+    def test_append_alt_id_exists(self):
+        """Test QueryResult.append, when alt ID exists"""
+        # append should raise an error if hit_key already exists as alt ID
+        hit11._id_alt = ['alt']
+        hit21._id_alt = ['alt']
+        qresult = QueryResult([hit11])
+        self.assertRaises(ValueError, qresult.append, hit21)
+        hit11._id_alt = []
+        hit21._id_alt = []
+
+    def test_append_alt_id_exists_alt(self):
+        """Test QueryResult.append, when alt ID exists as primary"""
+        # append should raise an error if alt ID already exists as primary ID
+        hit21._id_alt = ['hit1']
+        qresult = QueryResult([hit11])
+        self.assertRaises(ValueError, qresult.append, hit21)
+        hit21._id_alt = []
+
     def test_hit_filter(self):
         """Test QueryResult.hit_filter"""
         # hit_filter should return a new QueryResult object (shallow copy),
@@ -545,12 +660,33 @@ class QueryResultCases(unittest.TestCase):
         self.assertEqual(hit, hit21)
         self.assertEqual([hit11, hit31], list(self.qresult.hits))
 
+    def test_pop_string_alt_ok(self):
+        """Test QueryResult.pop, with alternative ID"""
+        # pop should work with alternative index
+        hit11._id_alt = ['alt1']
+        hit21._id_alt = ['alt2']
+        qresult = QueryResult([hit11, hit21])
+        hit = qresult.pop('alt1')
+        self.assertEqual(hit, hit11)
+        self.assertEqual([hit21], list(qresult))
+        self.assertTrue('hit1' not in qresult)
+        hit11._id_alt = []
+        hit21._id_alt = []
+
     def test_index(self):
         """Test QueryResult.index"""
         # index should accept hit objects or hit key strings
         self.assertEqual(2, self.qresult.index('hit3'))
         self.assertEqual(2, self.qresult.index(hit31))
 
+    def test_index_alt(self):
+        """Test QueryResult.index, with alt ID"""
+        # index should work with alt IDs
+        hit11._id_alt = ['alt1']
+        qresult = QueryResult([hit21, hit11])
+        self.assertEqual(1, qresult.index('alt1'))
+        hit11._id_alt = []
+
     def test_index_not_present(self):
         """Test QueryResult.index, when index is not present"""
         self.assertRaises(ValueError, self.qresult.index, 'hit4')
@@ -632,7 +768,7 @@ class HitCases(unittest.TestCase):
         hit = Hit([hsp111, hsp112, hsp113])
         self.assertEqual('hit1', hit.id)
         self.assertEqual('<unknown description>', hit.description)
-        self.assertEqual('query1', hit.query_id) # set from the HSPs
+        self.assertEqual('query1', hit.query_id)  # set from the HSPs
         self.assertEqual('<unknown description>', hit.query_description)
 
     def test_repr(self):
@@ -1409,5 +1545,5 @@ class HSPFragmentCases(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    runner = unittest.TextTestRunner(verbosity = 2)
+    runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
